@@ -1,4 +1,5 @@
 from .core import StrategyList
+from ..extended_set import ExtendedSet
 
 
 class ListStrategies(StrategyList):
@@ -26,5 +27,5 @@ class ListStrategies(StrategyList):
     @staticmethod
     def strategy_append_unique(config, path, base, nxt):
         """append items without duplicates in nxt to base."""
-        base_as_set = set(base)
+        base_as_set = ExtendedSet(base)
         return base + [n for n in nxt if n not in base_as_set]
